@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007,2008,2009,2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2011,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -40,7 +40,8 @@ private:
 };
 
 GnupgBinary::GnupgBinary()
-	: m_useDebugLevel(false)
+	: m_version(0),
+	m_useDebugLevel(false)
 {
 }
 
@@ -205,7 +206,7 @@ int GPGProc::readln(QString &line, const bool colons)
 	if (!readLineStandardOutput(&a))
 		return -1;
 
-	line = recode(a, colons);
+	line = recode(a, colons, m_codec);
 
 	return line.length();
 }
@@ -234,8 +235,9 @@ int GPGProc::readln(QStringList &l)
 }
 
 QString
-GPGProc::recode(QByteArray a, const bool colons)
+GPGProc::recode(QByteArray a, const bool colons, const QByteArray &codec)
 {
+	const char *textcodec = codec.isEmpty() ? "utf8" : codec.constData();
 	int pos = 0;
 
 	while ((pos = a.indexOf("\\x", pos)) >= 0) {
@@ -265,7 +267,19 @@ GPGProc::recode(QByteArray a, const bool colons)
 		} while ((npos = a.indexOf(pattern, npos)) >= 0);
 	}
 
-	return QTextCodec::codecForName("utf8")->toUnicode(a);
+	return QTextCodec::codecForName(textcodec)->toUnicode(a);
+}
+
+bool
+GPGProc::setCodec(const QByteArray &codec)
+{
+	const QList<QByteArray> codecs = QTextCodec::availableCodecs();
+	if (!codecs.contains(codec))
+		return false;
+
+	m_codec = codec;
+
+	return true;
 }
 
 int GPGProc::gpgVersion(const QString &vstr)
